Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.h

Issue 2644123003: Move ios/ui/suggestions to ios/ui/content_suggestions (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.h
diff --git a/ios/chrome/browser/ui/suggestions/suggestions_collection_updater.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.h
similarity index 68%
rename from ios/chrome/browser/ui/suggestions/suggestions_collection_updater.h
rename to ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.h
index 31a0c89771d8acccb0a28db43a5c16af540ef09d..b453f170f3aef3d11c1ac72ee57dae3d5233188f 100644
--- a/ios/chrome/browser/ui/suggestions/suggestions_collection_updater.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_collection_updater.h
@@ -2,16 +2,16 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_COLLECTION_UPDATER_H_
-#define IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_COLLECTION_UPDATER_H_
+#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_COLLECTION_UPDATER_H_
+#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_COLLECTION_UPDATER_H_
#import <UIKit/UIKit.h>
#import "ios/chrome/browser/ui/collection_view/collection_view_model.h"
-@class SuggestionsViewController;
+@class ContentSuggestionsViewController;
-// Enum defining the ItemType of this SuggestionsCollectionUpdater.
+// Enum defining the ItemType of this ContentSuggestionsCollectionUpdater.
typedef NS_ENUM(NSInteger, ItemType) {
ItemTypeText = kItemTypeEnumZero,
ItemTypeArticle,
@@ -22,12 +22,12 @@ typedef NS_ENUM(NSInteger, ItemType) {
// Updater for a CollectionViewController populating it with some items and
// handling the items addition.
-@interface SuggestionsCollectionUpdater : NSObject
+@interface ContentSuggestionsCollectionUpdater : NSObject
// |collectionViewController| this Updater will update. Needs to be set before
// adding items.
@property(nonatomic, assign)
- SuggestionsViewController* collectionViewController;
+ ContentSuggestionsViewController* collectionViewController;
// Adds a text item with a |title| and a |subtitle| in the section numbered
// |section|. If |section| is greater than the current number of section, it
@@ -41,4 +41,4 @@ typedef NS_ENUM(NSInteger, ItemType) {
@end
-#endif // IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_COLLECTION_UPDATER_H_
+#endif // IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_COLLECTION_UPDATER_H_

Powered by Google App Engine
This is Rietveld 408576698